BuildFactory typedef

BuildFactory = Widget Function(ElementTreeEntry model, [Iterable<Widget> subviews])

The Renderer is a function type that returns a widget representation of a DUITElement.

The function takes in a single parameter:

  • model: The DUITElement to be rendered.

It returns a Widget that represents the rendered DUITElement.

Implementation

typedef BuildFactory = Widget Function(
  ElementTreeEntry model, [
  Iterable<Widget> subviews,
]);