parseSync abstract method
Parses the JSON object to create a DuitElement object tree.
Returns a future that completes with the parsed ElementTree instance.
Implementation
ElementTree parseSync();
Parses the JSON object to create a DuitElement object tree.
Returns a future that completes with the parsed ElementTree instance.
ElementTree parseSync();