Parser<T> class abstract interface

A base interface for parsers in the DUIT library.

This interface defines a single method, parse, which takes in a JSON object and returns a parsed object of type T. This interface is used to define specific parsers for different types of data, such as UI elements, attributes, and scripts.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Map<String, dynamic> json) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited