TransportAction class final
A transport action represents an action that is executed using a transport mechanism.
A transport action is an action that requires communication with the server to be executed. It implements the DependentAction interface, which means it has dependencies that need to be resolved before execution. The action can also include optional metadata, represented by the meta property, which may contain additional information required for execution.
- Inheritance
-
- Object
- ServerAction
- TransportAction
- Implemented types
Constructors
-
TransportAction({required String eventName, required Iterable<
ActionDependency> dependsOn, HttpActionMetainfo? meta, ExecutionOptions? executionOptions, Duration? suppressionTTL, bool idempotent = false}) -
TransportAction.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
dependsOn
→ Iterable<
ActionDependency> -
The list of dependencies for the server action.
finalinherited
- eventName → String
-
The event associated with the server action.
finalinherited
- executionOptions → ExecutionOptions?
-
Optional execution behavior overrides (e.g., debounce, timeouts).
finalinherited
- executionType → int
-
Event execution type
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotent → bool
-
Whether the action is idempotent.
finalinherited
- meta → HttpActionMetainfo?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suppressionTTL → Duration?
-
The TTL of the action in seconds.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited